==> google-cloud-sdk-282.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/compute/org_security_policies/associations/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for listing the associations of an organization or folder resource."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.api_lib.compute.org_security_policies import client
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute.org_security_policies import flags


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Create(base.DescribeCommand):
  """List the associations of an organization or folder resource.

  *{command}* is used to list the associations of an organization or folder
   resource.
  """

  @classmethod
  def Args(cls, parser):
    flags.AddArgsListAssociation(parser)

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    org_security_policy = client.OrgSecurityPolicy(compute_client=holder.client)

    target_resource = None

    if args.IsSpecified('organization'):
      target_resource = 'organizations/' + args.organization

    elif args.IsSpecified('folder'):
      target_resource = 'folders/' + args.folder
    return org_security_policy.ListAssociations(
        target_resource=target_resource, only_generate_request=False)

==> google-cloud-sdk-285.0.1-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/compute/org_security_policies/associations/list.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command for listing the associations of an organization or folder resource."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.compute import base_classes
from googlecloudsdk.api_lib.compute.org_security_policies import client
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.compute.org_security_policies import flags


DEFAULT_LIST_FORMAT = """\
  table(
    name,
    displayName,
    securityPolicyId
  )"""


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Create(base.DescribeCommand, base.ListCommand):
  """List the associations of an organization or folder resource.

  *{command}* is used to list the associations of an organization or folder
   resource.
  """

  @classmethod
  def Args(cls, parser):
    flags.AddArgsListAssociation(parser)
    parser.display_info.AddFormat(DEFAULT_LIST_FORMAT)

  def Run(self, args):
    holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
    org_security_policy = client.OrgSecurityPolicy(compute_client=holder.client)

    target_resource = None

    if args.IsSpecified('organization'):
      target_resource = 'organizations/' + args.organization

    elif args.IsSpecified('folder'):
      target_resource = 'folders/' + args.folder
    res = org_security_policy.ListAssociations(
        target_resource=target_resource, only_generate_request=False)
    if not res:
      return None
    return res[0].associations
